from .DaleChallReadabilityTool import (
    DaleChallReadabilityTool as DaleChallReadabilityTool,
)

__version__ = "0.6.0.dev26"
__long_desc__ = """

# Swarmauri DaleChallReadability Tool Plugin

This repository includes an example of a Swarmauri Plugin.

Visit us at: https://swarmauri.com
Follow us at: https://github.com/swarmauri
Star us at: https://github.com/swarmauri/swarmauri-sdk

"""
